#[repr(C)]pub struct OrderFillVoided {Show 24 fields
pub trader_id: TraderId,
pub strategy_id: StrategyId,
pub instrument_id: InstrumentId,
pub client_order_id: ClientOrderId,
pub venue_order_id: VenueOrderId,
pub account_id: AccountId,
pub correction_id: Ustr,
pub trade_id: TradeId,
pub voided_qty: Quantity,
pub commission_voided: Option<Money>,
pub order_side: OrderSide,
pub order_type: OrderType,
pub last_px: Price,
pub currency: Currency,
pub liquidity_side: LiquiditySide,
pub position_id: Option<PositionId>,
pub reason: Option<Ustr>,
pub info: Option<IndexMap<Ustr, Ustr>>,
pub event_id: UUID4,
pub ts_event: UnixNanos,
pub ts_init: UnixNanos,
pub reconciliation: bool,
pub is_reopened: bool,
pub causation_id: Option<UUID4>,
}Expand description
Records that a cumulative fill quantity no longer has economic effect.
The correction identity, voided quantity, and commission are cumulative for the referenced
trade. is_reopened records positive evidence that the corrected order is executable again
and therefore requires the referenced fill to have been applied locally. Without a local fill,
a non-reopened correction is an authoritative terminal order void.
Fields
trader_id: TraderIdThe trader ID associated with the event.
strategy_id: StrategyIdThe strategy ID associated with the event.
instrument_id: InstrumentIdThe instrument ID associated with the event.
client_order_id: ClientOrderIdThe client order ID associated with the event.
venue_order_id: VenueOrderIdThe venue order ID associated with the event.
account_id: AccountIdThe account ID associated with the event.
correction_id: UstrThe venue identifier for the correction which voided the fill.
trade_id: TradeIdThe trade ID of the voided fill.
voided_qty: QuantityThe quantity removed from the order by the void.
commission_voided: Option<Money>The commission reversed by the void, if any.
order_side: OrderSideThe order side of the voided fill.
order_type: OrderTypeThe order type of the voided fill.
last_px: PriceThe last price of the voided fill.
currency: CurrencyThe currency of the voided fill.
liquidity_side: LiquiditySideThe liquidity side of the voided fill.
position_id: Option<PositionId>The position ID associated with the voided fill, if any.
reason: Option<Ustr>The reason the fill was voided.
info: Option<IndexMap<Ustr, Ustr>>The venue specific information for the void.
event_id: UUID4The unique identifier for the event.
ts_event: UnixNanosUNIX timestamp (nanoseconds) when the event occurred.
ts_init: UnixNanosUNIX timestamp (nanoseconds) when the event was initialized.
reconciliation: boolIf the event was generated during reconciliation.
is_reopened: boolIf the void reopened an order which had already closed.
causation_id: Option<UUID4>The causation ID associated with the event.
Implementations
Sourceimpl OrderFillVoided
impl OrderFillVoided
pub fn new( trader_id: TraderId, strategy_id: StrategyId, instrument_id: InstrumentId, client_order_id: ClientOrderId, venue_order_id: VenueOrderId, account_id: AccountId, correction_id: Ustr, trade_id: TradeId, voided_qty: Quantity, commission_voided: Option<Money>, order_side: OrderSide, order_type: OrderType, last_px: Price, currency: Currency, liquidity_side: LiquiditySide, position_id: Option<PositionId>, reason: Option<Ustr>, info: Option<IndexMap<Ustr, Ustr>>, event_id: UUID4, ts_event: UnixNanos, ts_init: UnixNanos, reconciliation: bool, is_reopened: bool, ) -> Self